@@ -4,6 +4,7 @@
  * Copyright (C) 2001 Havoc Pennington
  * Copyright (C) 2002 Red Hat, Inc.
  * Copyright (C) 2003 Rob Adams
+ * Copyright (C) 2004, 2005 Elijah Newren
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -223,6 +224,11 @@ struct _MetaDisplay
                               XErrorEvent *error);  
   int server_grab_count;
 
+  /* This window holds the focus when we don't want to focus
+   * any actual clients
+   */
+  Window no_focus_window;
+  
   /* for double click */
   Time last_button_time;
   Window last_button_xwindow;
@@ -413,9 +419,6 @@ void        meta_display_register_x_window   (MetaDisplay *display,
                                               MetaWindow  *window);
 void        meta_display_unregister_x_window (MetaDisplay *display,
                                               Window       xwindow);
-/* Return whether the xwindow is a no focus window for any of the screens */
-gboolean    meta_display_xwindow_is_a_no_focus_window (MetaDisplay *display,
-                                                       Window xwindow);
 
 GSList*     meta_display_list_windows        (MetaDisplay *display);
 
@@ -546,7 +549,6 @@ void meta_display_set_input_focus_window   (MetaDisplay *display,
  * same as meta_display_set_input_focus_window
  */
 void meta_display_focus_the_no_focus_window (MetaDisplay *display, 
-                                             MetaScreen  *screen,
                                              Time         timestamp);
 
 void meta_display_queue_autoraise_callback  (MetaDisplay *display,
